try:
    from django.utils import simplejson as json
except ImportError:
    import json
from django.http import HttpResponse

from .forms import NicEditImageForm


def upload(request):
    if not request.user.is_authenticated():
        json_data = json.dumps({
            'success': False,
            'errors': {'__all__': 'Authentication required'}})
        return HttpResponse(json_data, mimetype='application/json')
    form = NicEditImageForm(request.POST or None, request.FILES or None)
    if form.is_valid():
        image = form.save()
        json_data = json.dumps({
            'success': True,
            'upload': {
                'links': {
                    'original': image.image.url},
                'image': {
                    'width': image.image.width,
                    'height': image.image.height}
            }
        })
    else:
        json_data = json.dumps({
            'success': False, 'errors': form.errors})
    return HttpResponse(json_data, mimetype='application/json')



# -*- coding: utf-8 -*-
import json
from django import forms
from django.conf import settings
from django.contrib.staticfiles.storage import staticfiles_storage
from django.core.urlresolvers import reverse
from django.utils.safestring import mark_safe


class NicEditWidget(forms.Textarea):

    def __init__(self, *args, **kwargs):
        self.js_options = kwargs.pop('js_options', {})
        super(NicEditWidget, self).__init__(*args, **kwargs)

    class Media:
        js = (
            staticfiles_storage.url('js/nicedit.min.js'),
        )

    def render(self, name, value, attrs=None):

        rendered = super(NicEditWidget, self).render(name, value, attrs=attrs)
        return rendered + mark_safe(u'''
<script>
    new nicEditor(%s).panelInstance('id_%s');
</script>''' % (self.js_options, name))


class NicEditAdminWidget(NicEditWidget):

    def render(self, name, value, attrs=None):
        if not isinstance(self.js_options, (unicode, str)):
            self.js_options['uploadURI'] = reverse('nicedit_upload')
            self.js_options = json.dumps(self.js_options)
        rendered = super(NicEditWidget, self).render(name, value, attrs=attrs)
        return rendered + mark_safe(u'''
<script>
    var ta = document.getElementById('id_%s');
    if(ta) {
        var container = document.createElement('div');
        container.style.display = 'inline-block';
        container.style.float = 'left';
        ta.parentNode.insertBefore(container, ta);
        container.appendChild(ta);
        new nicEditor(%s).panelInstance(ta);
    }
</script>''' % (name, self.js_options))



import os

from StringIO import StringIO

from django.conf import settings
from django.contrib.auth.models import User
from django.core.urlresolvers import reverse
from django.test import TestCase
from django.utils import simplejson

from .models import NicEditImage


class ImageUploadTestCase(TestCase):

    def test_image_upload(self):
        self.assertFalse(NicEditImage.objects.exists())
        imagefile = StringIO('GIF87a\x01\x00\x01\x00\x80\x01\x00\x00\x00\x00ccc,\x00'
            '\x00\x00\x00\x01\x00\x01\x00\x00\x02\x02D\x01\x00;')
        imagefile.name = 'test_image.gif'
        response = self.client.post(reverse('nicedit_upload'), {})
        self.assertEqual(response.status_code, 200)
        data = simplejson.loads(response.content)
        self.assertEqual(data['success'], False)
        # unauthenticated
        response = self.client.post(
            reverse('nicedit_upload'), {'image': imagefile})
        self.assertEqual(response.status_code, 200)
        data = simplejson.loads(response.content)
        self.assertEqual(data['success'], False)
        # authentication
        user = User.objects.create_user(
            username='yoko', password='yoko', email='yoko@mail.com')
        result = self.client.login(
            username=user.username, password=user.username)
        self.assertTrue(result)
        imagefile.seek(0)
        response = self.client.post(
            reverse('nicedit_upload'), {'image': imagefile})
        self.assertEqual(response.status_code, 200)
        data = simplejson.loads(response.content)
        self.assertEqual(data['success'], True)
        self.assertIn(imagefile.name, data['upload']['links']['original'])
        self.assertEqual(NicEditImage.objects.count(), 1)
        image = NicEditImage.objects.latest('id')
        self.assertTrue(os.path.exists(image.image.path))
        os.remove(image.image.path)



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'NicEditImage'
        db.create_table(u'nicedit_niceditimage', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('image', self.gf('django.db.models.fields.files.ImageField')(max_length=100)),
        ))
        db.send_create_signal(u'nicedit', ['NicEditImage'])


    def backwards(self, orm):
        # Deleting model 'NicEditImage'
        db.delete_table(u'nicedit_niceditimage')


    models = {
        u'nicedit.niceditimage': {
            'Meta': {'object_name': 'NicEditImage'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'image': ('django.db.models.fields.files.ImageField', [], {'max_length': '100'})
        }
    }

    complete_apps = ['nicedit']